summaryrefslogtreecommitdiffstats
path: root/lib/xdsserver/events.go
diff options
context:
space:
mode:
authorSebastien Douheret <sebastien.douheret@iot.bzh>2018-02-23 18:45:15 +0100
committerSebastien Douheret <sebastien.douheret@iot.bzh>2018-02-23 18:45:15 +0100
commit65e09e831cf13343ac713fbf15281174d1f13a94 (patch)
tree0176a263ecf6d1059a272007c6f450770f5792ca /lib/xdsserver/events.go
parente97eebc18d726aa55738d7e19513491cf58a6e3a (diff)
Added target and terminal support.v1.1.0
Signed-off-by: Sebastien Douheret <sebastien.douheret@iot.bzh>
Diffstat (limited to 'lib/xdsserver/events.go')
-rw-r--r--lib/xdsserver/events.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/xdsserver/events.go b/lib/xdsserver/events.go
index 2528725..0a02ecd 100644
--- a/lib/xdsserver/events.go
+++ b/lib/xdsserver/events.go
@@ -35,8 +35,8 @@ type Events struct {
eventsMap map[string]*EventDef
}
-// NewEvents creates an instance of Events
-func NewEvents(ctx *Context) *Events {
+// EventsConstructor creates an instance of Events
+func EventsConstructor(ctx *Context) *Events {
evMap := make(map[string]*EventDef)
for _, ev := range xsapiv1.EVTAllList {
evMap[ev] = &EventDef{